<?php
include ('db.php');

session_start();
require_once './sealed/utils/FUNCOES.php';

function getApoios($id_user) {
    $apoio = array();
    $resultSocios = mysql_query("SELECT id FROM user "
            . " WHERE id_apoio = $id_user "
            . " AND status = 1");
    $apoio[] = $id_user;
    while ($rowSocios = mysql_fetch_array($resultSocios)) {
        $apoio[] = $rowSocios['id'];
    }
    return $apoio;
}

$queryCofig = "SELECT data_corte data FROM user WHERE id = " . $_SESSION['UsuarioID'] . "";
$result3 = mysql_query($queryCofig);
$rowc = mysql_fetch_array($result3);

if ($_SESSION['UsuarioNivel'] == 1)
{
    $idPais = $_REQUEST['idPais'];
    $query0 = "SELECT MAX(id) id FROM metricas GROUP BY idprod";
    $result = mysql_query($query0);
    while ($rowU = mysql_fetch_array($result))
	{
        $arrayMetricas[] = $rowU['id'];
    }
	
    //nova query para trazer os valores de comissão por Pais selecionado
    if ($idPais == 33)
	{
        $queryTop = "SELECT SUM(comissao_locacao) locacao,SUM(comissao_dono) dono, "
                . " SUM(comissao_ponto) ponto, SUM(saldo_total) saldo "
                . " FROM metricas, tablet , user , cobranca_agregado ca  "
                . " WHERE metricas.idprod = tablet.idprod "
                . " AND tablet.id_apoio = user.id"
                . " AND ca.id_cobranca = metricas.id_cobranca"
                . " AND metricas.dataorder > '" . date("Y-m-01 00:00:00") . "' "
                . " AND ca.id_cobranca = metricas.id_cobranca "
                . FUNCOES::returnSqlStatus('metricas' , 'BR')
                . " AND user.id_pais = '$idPais'";
    }
	else
	{
        $queryTop = "SELECT SUM(comissao_locacao) locacao,SUM(comissao_dono) dono,
                    SUM(comissao_ponto) ponto, SUM(saldo_total) saldo
                    FROM metricas, tablet , user , cobranca_agregado
                    WHERE metricas.idprod = tablet.idprod
                    AND tablet.id_apoio = user.id
                    AND cobranca_agregado.id_cobranca = metricas.id_cobranca
                    AND metricas.dataorder > '" . date("Y-m-01 00:00:00") . "'
                    AND metricas.ativo = 1"
                    . FUNCOES::returnSqlStatus('metricas')
                    . " AND user.id_pais = '$idPais'";
    }
}
elseif ($_SESSION['UsuarioNivel'] == 2)
{
    $idPais = $_REQUEST['idPais'];

    $queryTop = "SELECT SUM(comissao_locacao) AS locacao, SUM(comissao_dono) AS dono,
        SUM(comissao_ponto) AS ponto, SUM(saldo_total) AS saldo
					FROM metricas a
					INNER JOIN tablet b ON b.idprod = a.idprod
					INNER JOIN user c ON c.username = b.cliente
					WHERE
					a.dataorder > '$rowc[data]'
					AND a.ativo = 1
					AND c.afiliado = 1
                                        AND c.id_pais = '$idPais'
					AND a.status_leitura <> 2
					AND a.status <> 0";
}
elseif ($_SESSION['UsuarioNivel'] == 3) {

    $apoios = getApoios($_SESSION[UsuarioID]);

    $idPais = $_REQUEST['idPais'];
  
    if ($idPais == 33)
	{
        /**
         * BRASIL
         */
        $queryTop = "SELECT ca.id_cobranca,sum(comissao_locacao) locacao,sum(comissao_dono) dono, "
                . " sum(comissao_ponto) ponto, sum(saldo_total) saldo,metricas.idprod "
                . " FROM metricas,  tablet , cobranca_agregado ca "
                . " WHERE metricas.idprod = tablet.idprod "
                . " AND tablet.id_apoio IN (" . implode(',', $apoios) . ")  "
                //. " AND tablet.id_apoio = user.id  "
                . " AND ca.id_cobranca = metricas.id_cobranca "
                . " AND metricas.dataorder > '$rowc[data]' "
                . FUNCOES::returnSqlStatus('metricas' , 'BR');
    }
	else
	{
        $queryTop = "SELECT SUM(comissao_locacao) locacao,SUM(comissao_dono) dono, "
                . " SUM(comissao_ponto) ponto, SUM(saldo_total) saldo "
                . " FROM metricas, "
                . " tablet WHERE metricas.idprod = tablet.idprod "
                . " AND tablet.id_apoio IN (" . implode(',', $apoios) . ") "
                . " AND metricas.dataorder > '$rowc[data]' "
                . " AND metricas.ativo = 1 "
                . FUNCOES::returnSqlStatus('metricas');
    }
}
elseif ($_SESSION['UsuarioNivel'] == 4)
{
    /**
     * SÓCIO
     */
    
    $queryu = "SELECT porcentagem FROM user WHERE id =  " . $_SESSION['UsuarioID'];
    $result = mysql_query($queryu);
    $rowU = mysql_fetch_array($result);
    if ($rowU['porcentagem'] <> 0) {
        $colunm_locacao = "  IFNULL(round(SUM((select porcentagem from user where id = " . $_SESSION['UsuarioID'] . ") /100 * metricas.acerto)),0) locacao";
    } else {
        $colunm_locacao = " IFNULL(SUM(c.comissao_locacao),0) AS locacao";
    }

    if ($rowU['porcentagem'] <> 0)
	{
        $colunm_locacao = "  IFNULL(round(SUM((select porcentagem from user where id = " . $_SESSION['UsuarioID'] . ") /100 * a.acerto)),0) locacao";
    }
    if ($idPais == 33)
	{
          $queryTop = "SELECT $colunm_locacao, IFNULL(SUM(c.comissao_dono), 0) AS dono, IFNULL(SUM(c.comissao_ponto), 0) AS ponto, IFNULL(SUM(c.saldo_total), 0) AS saldo
						FROM metricas a, tablet b, metrica_parcial c , cobranca_agregado ca
						WHERE
						a.idprod = b.idprod
						AND b.id_apoio = '$_SESSION[UsuarioID]'
						AND a.dataorder > '$rowc[data]'
						AND a.ativo = 1
						AND b.ativo = 1
						AND c.id_metrica_fk = a.id
                                                AND ca.id_cobranca = a.id_cobranca 
						AND c.data_zerou_parcial IS NULL"
						. FUNCOES::returnSqlStatus('a' , 'BR')
                                                . " GROUP BY ca.id_cobranca";
          
    }
	else
	{
        $queryTop = "SELECT $colunm_locacao, IFNULL(SUM(c.comissao_dono), 0) AS dono, IFNULL(SUM(c.comissao_ponto), 0) AS ponto, IFNULL(SUM(c.saldo_total), 0) AS saldo
						FROM metricas a, tablet b, metrica_parcial c
						WHERE
						a.idprod = b.idprod
						AND b.id_apoio = '$_SESSION[UsuarioID]'
						AND a.dataorder > '$rowc[data]'
						AND a.ativo = 1
						AND b.ativo = 1
						AND c.id_metrica_fk = a.id
						AND c.data_zerou_parcial IS NULL"
						. FUNCOES::returnSqlStatus('a');
    }
}
elseif ($_SESSION['UsuarioNivel'] == 6)
{
    $idPais = $_REQUEST['idPais'];
	
    if ($idPais == 33)
	{
        /**
         * BRASIL
         */
        $queryTop = "SELECT SUM(comissao_locacao) locacao,SUM(comissao_dono) dono, "
                . " SUM(comissao_ponto) ponto, SUM(saldo_total) saldo "
                . " FROM metricas, tablet, user a , cobranca_agregado ca"
                . " WHERE metricas.idprod = tablet.idprod "
                . " AND tablet.id_ponto = a.id_apoio "
                . " AND a.id = " . $_SESSION['UsuarioID']
                . " AND metricas.dataorder > '$rowc[data]' "
                . " AND metricas.ativo = 1 "
                . FUNCOES::returnSqlStatus('metricas' , 'BR')
                . " GROUP BY ca.id_cobranca";
    }
	else
	{
        $queryTop = "SELECT SUM(comissao_locacao) locacao,SUM(comissao_dono) dono, "
                . " SUM(comissao_ponto) ponto, SUM(saldo_total) saldo "
                . " FROM metricas, tablet, user a "
                . " WHERE metricas.idprod = tablet.idprod "
                . " AND tablet.id_ponto = a.id_apoio "
                . " AND a.id = " . $_SESSION['UsuarioID']
                . " AND metricas.dataorder > '$rowc[data]' "
                . " AND metricas.ativo = 1 "
                . " AND tablet.ativo = 1"
                . FUNCOES::returnSqlStatus('metricas');
    }
}
else
{
    $queryTop = "SELECT SUM(comissao_locacao) locacao,SUM(comissao_dono) dono, SUM(comissao_ponto) ponto, SUM(saldo_total) saldo FROM metricas, tablet WHERE metricas.idprod = tablet.idprod AND tablet.id_apoio = " . $_SESSION['UsuarioApoio'] . " AND metricas.dataorder > '$rowc[data]' AND metricas.ativo = 1 AND tablet.ativo = 1
					AND metricas.status_leitura <> 2
					AND metricas.status <> 0";
}

$result1 = mysql_query($queryTop) or die(mysql_error());
$row = mysql_fetch_array($result1);

$totallocacao = $row['locacao'];
$totaldono = $row['dono'];
$totalponto = $row['ponto'];
$totalsaldo = $row['saldo']; //($totallocacao+$totaldono+$totalponto); //$row['saldo'];

$first_quadrante = 'Locação a pagar';

if ($_SESSION['UsuarioNivel'] == 4 && $rowU['porcentagem'] <> 0) {
    /**
     * SÓCIO
     */
//    $totaldono = $totallocacao - $totalponto;
    $totaldono = $totalsaldo - ($totalponto + $totallocacao);
}

if ($_SESSION['UsuarioNivel'] == 1) {
    /**
     * ADMIN
     */
    $idPais = $_REQUEST['idPais'];
    $comissao_socio = 0;
    $totallocacao = 0;
    $query = "SELECT a.id AS id, c.cliente AS nome, c.idprod, comissao_dono, comissao_locacao, comissao_ponto, acerto, saldo_total AS saldo,
									DATE_FORMAT(a.dataorder,'%d/%m/%Y %H:%i') dataorder, d.id_pais, e.moeda_sigla ,c.id_apoio
									FROM metricas a, ponto b, tablet c, user d, regiao e,cobranca_agregado ca, (
										SELECT MAX(id) id
										FROM metricas
										GROUP BY idprod
										ORDER BY id
									) mx
									WHERE
									a.idprod = c.idprod
									AND c.id_ponto = b.id
                                                                        AND ca.id_cobranca = a.id_cobranca
									AND a.id = mx.id
									AND d.username = c.cliente
									AND e.id_pais = d.id_pais
									AND d.id_pais = '$idPais'
                                                                        AND a.dataorder > '".date("Y-m-01 00:00:00")."' 
									AND ca.lote_fechamento_hash IS NULL";
    $result = mysql_query($query) or die(mysql_error());

    if (mysql_num_rows($result) > 0) {
        while (($row2 = mysql_fetch_array($result))) {
            $queryuser = "SELECT nivel,porcentagem FROM user "
                    . " WHERE id IN(" . $row2['id_apoio'] . ") "
                    . " AND nivel = 4";
            $resultuser3 = mysql_query($queryuser);
            $rowUser3 = mysql_fetch_array($resultuser3);
            if ($rowUser3['porcentagem']) {
                $comissoes = $row2['comissao_dono'] + $row2['comissao_locacao'] + $row2['comissao_ponto'];
                $row2['comissao_dono']+= $row2['acerto'] - $comissoes;
                $totallocacao += $row2['comissao_dono'];
            }
            //$totallocacao += $row2['comissao_dono'];
        }
    }

    $first_quadrante = 'Comissão Clientes';
    $totallocacao+= $row['dono'];
    $totaldono = $row['locacao'];
    //$totalsaldo +=$comissao_socio;
}

if ($_SESSION['UsuarioNivel'] == 3) {
    /**
     * CLIENTE - comissão do sócio
     */
    if ($result1) {
        $comissao_socio = '0';
        $apoios = getApoios($_SESSION[UsuarioID]);
        $querySocio = "SELECT tablet.id_apoio ,comissao_dono,comissao_locacao,
                       comissao_ponto,  acerto, saldo_total saldo
                        FROM metricas,ponto,tablet,cobranca_agregado ca,
                        (select MAX(id) id
                         from metricas group by idprod ORDER BY metricas.id) mx  "
                . " WHERE metricas.idprod = tablet.idprod "
                . " AND ca.id_cobranca = metricas.id_cobranca "
                . " AND tablet.id_ponto = ponto.id "
                . " AND metricas.ID = mx.id "
                . " AND tablet.id_apoio IN (" . implode(',', $apoios) . ')'
                . " AND ( (metricas.status_leitura  = 2  "
                . "        AND ca.lote_fechamento_hash IS NOT NULL AND metricas.status = 0)"
                . "        OR "
                . "       (metricas.status_leitura <> 2  "
                . "        AND ca.lote_fechamento_hash IS NULL AND metricas.status <> 0) ) "
                . " AND metricas.dataorder > '$rowc[data]' "
                . " AND metricas.cliente_fechamento IS NULL"
                . "   ";
        $resultSocio = mysql_query($querySocio) or die(mysql_error());
        while ($rowResumo = mysql_fetch_array($resultSocio)) {
            $queryuser = "SELECT nivel,porcentagem FROM user "
                    . " WHERE id =  " . $rowResumo['id_apoio'];
            $resultuser3 = mysql_query($queryuser);
            $rowUser3 = mysql_fetch_array($resultuser3);
            if ($rowUser3['porcentagem']) {
                if ($rowUser3['nivel'] == 4) { //caso comissao_sócio
                    $comissoes = $rowResumo['comissao_dono'] + $rowResumo['comissao_locacao'] + $rowResumo['comissao_ponto'];
                    $comissao_socio += $rowResumo['acerto'] - $comissoes;
                }
            }
        }
    }
}

if (empty($row['dono'])) {
    $totaldono = 0;
    $totalponto = 0;
    $totalsaldo = 0;
    if ($totallocacao == 0) {
        $totallocacao = 0;
    }
}

if ($_SESSION['UsuarioNivel'] < 6) {
    if ($_SESSION['UsuarioNivel'] == 3) {
        $with_quadrante = '20%';
        $with_quadrante = '2';
    } else {
        $with_quadrante = '25%';
        $with_quadrante = '3';
    }
    

    ?>

    <div class="col-lg-<?= $with_quadrante ?>" >
        <div class="panel panel-info">
            <div class="panel-heading">
                <div class="row">
                    <div class="col-xs-3">
                        <i class="fa fa-tablet fa-3x"></i>
                    </div>
                    <div class="col-lg-9 text-center">
                        <p class="announcement-text"><?= $first_quadrante ?></p>
                    </div>
                    <div class="col-lg-9 text-center">
                        <p class="announcement-heading-text"><h3><?php echo $_SESSION['cifraoMoeda'] . $totallocacao; ?></h3></p>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!--3-6-5-->
    <div class="col-lg-<?= $with_quadrante ?>">
        <div class="panel panel-success">
            <div class="panel-heading">
                <div class="row">
                    <div class="col-xs-3">
                        <i class="fa fa-user fa-3x"></i>
                    </div>
                    <div class="col-lg-9 text-center">
                        <p class="announcement-text">Minha Comissão</p>
                    </div>
                    <div class="col-lg-9 text-center">
                        <p class="announcement-heading-text"><h3><?php echo $_SESSION['cifraoMoeda'] . $totaldono; ?></h3></p>
                    </div>
                </div>
            </div>

        </div>
    </div>
    <?php if ($_SESSION['UsuarioNivel'] == 3) { ?>
        <div class="col-lg-<?= $with_quadrante ?>">
            <div class="panel panel-warning">
                <div class="panel-heading">
                    <div class="row">
                        <div class="col-xs-3">
                            <i class="fa fa-user fa-3x"></i>
                        </div>
                        <div class="col-lg-9 text-center">
                            <p class="announcement-text"><?= 'Comissão Sócio' ?></p>
                        </div>
                        <div class="col-lg-9 text-center">
                            <p class="announcement-heading-text"><h3><?php echo $_SESSION['cifraoMoeda'] . $comissao_socio; ?></h3></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php } ?>
    <?php
}else{
      $with_quadrante = '3';
}

?>

<div class="col-lg-<?=$with_quadrante ?>">
    <div class="panel panel-danger">
        <div class="panel-heading">
            <div class="row">
                <div class="col-xs-3">
                    <i class="fa fa-home fa-3x"></i>
                </div>
                <div class="col-lg-9 text-center">
                    <p class="announcement-text">Comissão Pontos</p>
                </div>
                <div class="col-lg-9 text-center">
                    <p class="announcement-heading-text"><h3><?php echo $_SESSION['cifraoMoeda'] . $totalponto; ?></h3></p>
                </div>
            </div>
        </div>

    </div>
</div>

<div class="col-lg-<?=$with_quadrante ?>">
    <div class="panel panel-info">
        <div class="panel-heading">
            <div class="row">
                <div class="col-xs-3">
                    <i class="fa fa-adjust fa-3x"></i>
                </div>
                <div class="col-lg-9 text-center">
                    <p class="announcement-text">Total de Saldos</p>
                </div>
                <div class="col-lg-9 text-center">
                    <p class="announcement-heading-text"><h3><?php echo $_SESSION['cifraoMoeda'] . ($totalsaldo); ?></h3></p>
                </div>
            </div>
        </div>
    </div>
</div>